package anywheresoftware.b4a.RSA;

import anywheresoftware.b4a.BA.ShortName;

import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.math.BigInteger;

import anywheresoftware.b4a.RSA.utils.ExceptionType;
import anywheresoftware.b4a.RSA.utils.JLibraryException;
import anywheresoftware.b4a.RSA.utils.RSAPrivateKey;
import anywheresoftware.b4a.RSA.utils.RSAUtils;

@ShortName("CipherInputStream")
/**
 * This class overrides inputStream and decrypt a stream while reading
 * 
 * @author pmartinez
 *
 */
public class CipherInputStream extends FilterInputStream {
	private RSAPrivateKey key;

	/**
	 * Constructs an input stream that will be decrypting its content while
	 * reading with the private key in the cipher element
	 * 
	 * @param is
	 *            inputStream to decode
	 * @param c
	 *            cipher element containing the private key to decrypt
	 */
	public CipherInputStream(InputStream is, Cipher c) {
		super(is);
		this.key = c.getCipherKey().getPrivateKey();
	}

	@Override
	public int read() throws IOException {
		if (key == null)
			try {
				throw new JLibraryException(ExceptionType.NO_PRIVATE_KEY);
			} catch (JLibraryException e) {
				throw new IOException(e.getMessage());
			}

		int read = super.read();
		if (read == -1)
			return -1;
		byte[] bytesRead = BigInteger.valueOf(read).toByteArray();
		byte[] bytes = RSAUtils.decrypt(bytesRead, key);
		return new BigInteger(bytes).intValue();
	}

	@Override
	public int read(byte[] b, int off, int len) throws IOException {
		if (key == null)
			try {
				throw new JLibraryException(ExceptionType.NO_PRIVATE_KEY);
			} catch (JLibraryException e) {
				throw new IOException(e.getMessage());
			}

		byte[] read = new byte[b.length];
		int ret = super.read(read, off, len);
		if (ret == -1)
			return -1;
		b = RSAUtils.decrypt(read, key);
		return ret;
	}
}
