package anywheresoftware.b4a.RSA;

import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.RSA.utils.ExceptionType;
import anywheresoftware.b4a.RSA.utils.JLibraryException;
import anywheresoftware.b4a.RSA.utils.RSAPublicKey;
import anywheresoftware.b4a.RSA.utils.RSAUtils;

import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.math.BigInteger;

@ShortName("CipherOutputStream")
/**
 * This class overrides outputStream and encrypt a stream while writing
 * 
 * @author pmartinez
 *
 */
public class CipherOutputStream extends FilterOutputStream {

	private RSAPublicKey key;

	/**
	 * Constructs an output stream that will be encrypting its content while
	 * writing with the public key in the cipher element
	 * 
	 * @param out
	 *            Outputstream to encrypt
	 * @param c
	 *            cipher element containing the public key to encrypt
	 */
	public CipherOutputStream(OutputStream out, Cipher c) {
		super(out);
		this.key = c.getCipherKey().getPublicKey();
	}

	@Override
	public void write(byte[] b) throws IOException {
		if (key == null)
			try {
				throw new JLibraryException(ExceptionType.NO_PUBLIC_KEY);
			} catch (JLibraryException e) {
				throw new IOException(e.getMessage());
			}
		byte[] temp = new byte[b.length];
		super.write(temp);
		b = RSAUtils.encrypt(temp, key);
	}

	@Override
	public void write(int b) throws IOException {
		if (key == null)
			try {
				throw new JLibraryException(ExceptionType.NO_PUBLIC_KEY);
			} catch (JLibraryException e) {
				throw new IOException(e.getMessage());
			}
		int writed = 0;
		super.write(writed);
		byte[] temp = BigInteger.valueOf(writed).toByteArray();
		b = new BigInteger(RSAUtils.encrypt(temp, key)).intValue();
	}

}
