package anywheresoftware.b4a.RSA.utils;

import anywheresoftware.b4a.BA.ShortName;
import java.math.BigInteger;

@ShortName("RSAPrivateKey")

/**
 * This class represents the private key for a RSA Algorithm
 * @author pmartinez
 *
 */
public class RSAPrivateKey {
	private BigInteger d;
	private BigInteger n;

	/**
	 * Creates the private key object with the given secret exponent and modulus
	 * @param d the secret exponent
	 * @param n the modulus
	 */
	public RSAPrivateKey(BigInteger d, BigInteger n) {
		super();
		this.d = d;
		this.n = n;
	}

	/**
	 * Get the secret exponent (a.k.a. decryption exponent)
	 * @return the secret exponent
	 */
	public BigInteger getD() {
		return d;
	}

	/**
	 * Set the secret exponent (a.k.a. decryption exponent)
	 * @param d the secret exponent
	 */
	public void setD(BigInteger d) {
		this.d = d;
	}

	/**
	 * Get the modulus (n=pq)
	 * @return the modulus for the private key
	 */
	public BigInteger getN() {
		return n;
	}

	/**
	 * Set the modulus for the private key
	 * @param n modulus to set
	 */
	public void setN(BigInteger n) {
		this.n = n;
	}

}
