package anywheresoftware.b4a.RSA.utils;

import anywheresoftware.b4a.BA.ShortName;
import java.math.BigInteger;

@ShortName("RSAPublicKey")
/**
 * This class represents the public class for a RSA Algorithm
 * @author pmartinez
 *
 */
public class RSAPublicKey {
	private BigInteger e;
	private BigInteger n;

	/**
	 * Creates the private key object with the given public exponent and modulus
	 * @param e the public exponent
	 * @param n the modulus
	 */
	public RSAPublicKey(BigInteger e, BigInteger n) {
		super();
		this.e = e;
		this.n = n;
	}

	/**
	 * Get the public exponent (a.k.a. encryption exponent)
	 * @return the secret exponent
	 */
	public BigInteger getE() {
		return e;
	}

	/** 
	 * Set the public exponent (a.k.a. encryption exponent)
	 * @param e the secret exponent
	 */
	public void setE(BigInteger e) {
		this.e = e;
	}

	/**
	 * Get the modulus (n=pq)
	 * @return the modulus for the private key
	 */
	public BigInteger getN() {
		return n;
	}

	/**
	 * Set the modulus for the private key
	 * @param n modulus to set
	 */
	public void setN(BigInteger n) {
		this.n = n;
	}

}
